@@ -3,10 +3,9 @@
 
 import time
 import board
-import busio
 import adafruit_ccs811
 
-i2c = busio.I2C(board.SCL, board.SDA)
+i2c = board.I2C()  # uses board.SCL and board.SDA
 ccs811 = adafruit_ccs811.CCS811(i2c)
 
 # Wait for the sensor to be ready
